@@ -21,8 +21,11 @@ from data_point_client.models import GetConstantResponse, GetSeriesResponse
 from data_point_client.models.append_execution_result_data_request import AppendExecutionResultDataRequest
 from data_point_client.models.append_time_series_request import AppendTimeSeriesRequest
 from data_point_client.models.data_point_request import DataPointRequest
+from data_point_client.models.day_data_by_hour_transfer import DayDataByHourTransfer
 from data_point_client.models.en_data_point_existence_dto import EnDataPointExistenceDTO
 from data_point_client.models.get_data_request import GetDataRequest
+from data_point_client.models.get_day_period_response import GetDayPeriodResponse
+from data_point_client.models.get_week_period_response import GetWeekPeriodResponse
 from data_point_client.models.problem_details import ProblemDetails
 from data_point_client.models.sub_series_request import SubSeriesRequest
 from data_point_client.models.sub_series_request_values import SubSeriesRequestValues
@@ -96,7 +99,7 @@ class NistaDataPoint:
     # pylint: disable=too-many-arguments
     def get_data_point_data(
         self, request: GetDataRequest, post_fix: bool = False, timeout: float = 30
-    ) -> Union[List[DataFrame], float, Unset, None]:
+    ) -> Union[List[DataFrame], float, Unset, WeekDataTransfere, DayDataByHourTransfer, None]:
         token = self.connection.get_access_token()
         client = AuthenticatedClient(
             base_url=self.connection.datapoint_base_url,
@@ -141,6 +144,16 @@ class NistaDataPoint:
             if constant_response is not None:
                 return constant_response.value
 
+        if content_type == "GetWeekPeriodResponse":
+            week_response = GetWeekPeriodResponse.from_dict(jscon_content)
+            if week_response is not None:
+                return week_response.week_data
+
+        if content_type == "GetDayPeriodResponse":
+            day_response = GetDayPeriodResponse.from_dict(jscon_content)
+            if day_response is not None:
+                return day_response.day_data
+
         return None
 
     def append_data_point_data(
